@@ -62,7 +62,7 @@
 #define CALENDARSUPPORT_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef CALENDARSUPPORT_NO_DEPRECATED
-#  define CALENDARSUPPORT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x60550
+#  define CALENDARSUPPORT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x6055a
 #endif
 #ifdef CALENDARSUPPORT_NO_DEPRECATED_WARNINGS
 #  define CALENDARSUPPORT_DEPRECATED_WARNINGS_SINCE 0
@@ -72,7 +72,7 @@
 #  ifdef CALENDARSUPPORT_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define CALENDARSUPPORT_DEPRECATED_WARNINGS_SINCE CALENDARSUPPORT_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define CALENDARSUPPORT_DEPRECATED_WARNINGS_SINCE 0x60550
+#    define CALENDARSUPPORT_DEPRECATED_WARNINGS_SINCE 0x6055a
 #  endif
 #endif
 
